@@ -698,7 +698,7 @@ int Cribbage::scoreRuns(const CardProperties &cardProperties)
 int Cribbage::removePairPoints(const CardSequence &run)
 {
     CardSequence pair; //Is the pair in the run.
-    bool foundPair;
+    bool foundPair=false;
 
     //Find our pair
     for (int i=0; i < (run.size()-1); ++i)
@@ -708,6 +708,7 @@ int Cribbage::removePairPoints(const CardSequence &run)
                 pair.addCard(run[i]);
             pair.addCard(run[i+1]);
         }
+
     // Remove pair from m_cardSummary and m_messageSummary
     for (int cardSummaryIndex=0; cardSummaryIndex < static_cast<int>(m_cardSummary.size()); ++cardSummaryIndex)
     {
@@ -754,7 +755,7 @@ int Cribbage::removePairPoints(const CardSequence &run)
             }
         }
         else
-            throw KardsGTError("Cribbage", "removePairPoints", "Failed to handle pair type!");
+            throw KardsGTError("Cribbage", "removePairPoints", "A run with no pairs was passed in; failed to handle pair type!");
         if (foundPair)
         {
             vector<CardSequence>::iterator cardIter=m_cardSummary.begin();
